@@ -5,13 +5,12 @@
 Utilities for sending files over ssh using the scp1 protocol.
 """
 
-__version__ = '0.13.5'
+__version__ = '0.14.0'
 
 import locale
 import os
 import re
 from socket import timeout as SocketTimeout
-import types
 
 
 # this is quote from the shlex module, added in py3.3
@@ -19,6 +18,15 @@ _find_unsafe = re.compile(br'[^\w@%+=:,./~-]').search
 
 SCP_COMMAND = b'scp'
 
+PATH_TYPES = (str, bytes)
+
+try:
+    import pathlib
+except ImportError:
+    pass
+else:
+    PATH_TYPES += pathlib.PurePath,
+
 
 def _sh_quote(s):
     """Return a shell-escaped version of the string `s`."""
@@ -41,6 +49,8 @@ def asbytes(s):
     """
     if isinstance(s, bytes):
         return s
+    elif pathlib and isinstance(s, pathlib.Path):
+        return bytes(s)
     else:
         return s.encode('utf-8')
 
@@ -160,8 +170,10 @@ class SCPClient(object):
                                   self.sanitize(asbytes(remote_path)))
         self._recv_confirm()
 
-        if not isinstance(files, (list, tuple)):
+        if isinstance(files, PATH_TYPES):
             files = [files]
+        else:
+            files = list(files)
 
         if recursive:
             self._send_recursive(files)
@@ -214,8 +226,10 @@ class SCPClient(object):
             and directories.
         @type preserve_times: bool
         """
-        if not isinstance(remote_path, (list, tuple)):
+        if isinstance(remote_path, PATH_TYPES):
             remote_path = [remote_path]
+        else:
+            remote_path = list(remote_path)
         remote_path = [self.sanitize(asbytes(r)) for r in remote_path]
         self._recv_dir = local_path or os.getcwd()
         self._depth = 0
@@ -320,13 +334,15 @@ class SCPClient(object):
 
     def _send_recursive(self, files):
         for base in files:
+            base = asbytes(base)
             if not os.path.isdir(base):
                 # filename mixed into the bunch
                 self._send_files([base])
                 continue
             last_dir = asbytes(base)
             for root, dirs, fls in os.walk(base):
-                self._chdir(last_dir, asbytes(root))
+                if not asbytes(root).endswith(b'/'):
+                    self._chdir(last_dir, asbytes(root))
                 self._send_files([os.path.join(root, f) for f in fls])
                 last_dir = asbytes(root)
             # back out of the directory
